

package com.fiorano.esb.service.filenamedconfig.model;

import com.fiorano.edbc.framework.service.configuration.ConnectionlessServiceConfiguration;
import com.fiorano.edbc.framework.service.exception.ServiceConfigurationException;
import com.fiorano.edbc.framework.service.exception.ServiceErrorID;
import com.fiorano.edbc.framework.service.exception.ServiceException;
import com.fiorano.services.common.annotations.NamedConfiguration;
import com.fiorano.util.ErrorListener;
import com.fiorano.util.lang.ClassUtil;
import fiorano.esb.utils.RBUtil;
import com.fiorano.esb.service.filenamedconfig.Bundle;

import java.net.URL;
import java.util.*;
import com.fiorano.edbc.framework.service.exception.ErrorHandlingAction;


/**
 * PropertyModel class captures the configuration information from the
 * Custom Property Sheet (CPS) of the component.
 * set methods set the property to the values provided in CPS and get methods
 * can be used to get those values.
 * JMX Naming conventions should be followed for these method names.
 *
 * @fiorano.xmbean
 * @jmx.mbean
 * @jboss.xmbean
 */
public class FileNamedConfigPM extends ConnectionlessServiceConfiguration {

    /**
     * Sample property of the component which is captured from the Custom Property Sheet.
     */
    private String myProperty="sample property";
    
    private FileConfiguration fileConfiguration = new FileConfiguration();
	
    /**
     * Creates an instance of Property Model.
     */	
	@SuppressWarnings("rawtypes")
	public FileNamedConfigPM() {
	 Iterator errorActionsIterator = errorHandlingConfiguration.getErrorActionsMap().entrySet().iterator();
        while (errorActionsIterator.hasNext()) {
            Map.Entry entry = (Map.Entry) errorActionsIterator.next();
            Set actions = (Set) entry.getValue();
            boolean isJMSError = ServiceErrorID.TRANSPORT_ERROR.equals(entry.getKey());
            for (Iterator iterator = actions.iterator(); iterator.hasNext();) {
                ErrorHandlingAction errorHandlingAction = (ErrorHandlingAction) iterator.next();
                if (errorHandlingAction.getId() == ErrorHandlingAction.LOG || errorHandlingAction.getId() == ErrorHandlingAction.SEND_TO_ERROR_PORT) {
                    errorHandlingAction.setEnabled(true);
                }
                if (isJMSError && errorHandlingAction.getId() == ErrorHandlingAction.STOP_SERVICE) {
                    errorHandlingAction.setEnabled(true);
                }
            }
        }        
	}

    /**
     * Returns the value of myProperty.
     *
     * @jmx.managed-attribute access="read-write" description="this is a sample property"
     * @jmx.descriptor name="displayName" value="My Property"
     * @jmx.descriptor name="defaultValue" value="sample property"
     * @jmx.descriptor name="index" value="0"
     */
    public String getMyProperty() {
        return myProperty;
    }

    /**
     * Sets the value of myProperty.
     *
     * @jmx.managed-attribute
     */
    public void setMyProperty(String val) {
        myProperty = val;
    }
    
    /**
     *@jmx.managed-attribute access="read-write" description="File Named Configuration"
     *@jmx.descriptor name="displayName" value="File Configuration"
     *@jmx.descriptor name="index" value="2"
     *@jmx.descriptor name="Editor" value="com.fiorano.esb.service.filenamedconfig.swt.editor.FileConfigurationEditor"
     */ 
    @NamedConfiguration
     public FileConfiguration getFileConfiguration() {
         return fileConfiguration;
     }

    /**
     *@jmx.managed-attribute
     */ 
     public void setFileConfiguration(FileConfiguration fileConfiguration) {
         this.fileConfiguration = fileConfiguration;
     }

    /**
     * Validates the configuration parameters in the panel.
     * @param Listener error listener used to notify errors
     * @throws ServiceConfigurationException if there is any exception in validation
     */
    public void validate(ErrorListener Listener) throws ServiceConfigurationException {
        boolean errorOccured = false;
        if (myProperty == null || myProperty.trim().equals("")) {
            if (Listener != null) {
                errorOccured = errorOccured | notifyErrorListener(Listener, new ServiceConfigurationException(
                        "Specify My Property", ServiceErrorID.INVALID_CONFIGURATION_ERROR));
            } else {
                throw new ServiceConfigurationException("Specify My Property",
                                                        ServiceErrorID.INVALID_CONFIGURATION_ERROR);
            }
        }

        if (errorOccured) {
            throw new ServiceConfigurationException(RBUtil.getMessage(Bundle.class, Bundle.INVALID_CONFIGURATION),
                                                    ServiceErrorID.INVALID_CONFIGURATION_ERROR);
        }
    }

    /**
    * Notifies error listener of an exception.
    * @param errorListener error listener
    * @param exceptionToNotify exception to be notified
    * @return boolean specifying whether the error listener is notified
    * @throws ServiceConfigurationException if there is any exception while notifying
    */
    protected final boolean notifyErrorListener(ErrorListener errorListener, Exception exceptionToNotify) throws ServiceConfigurationException {
        if (exceptionToNotify == null) {
            return false;
        }
        try {
            errorListener.error(exceptionToNotify);
        } catch (Exception e) {
            throw new ServiceConfigurationException(ServiceErrorID.INVALID_CONFIGURATION_ERROR);
        }
        return true;
    }

    /**
     * Overridden method which tests the component's logic.
     */
    public void test() throws ServiceException {
    }
	
    /**
     * Overridden method generally used for logging.
     */
    public String getAsFormattedString() {
        return "";
    }

    /**
     * @return help URL
     * @jmx.managed-operation description="Help set URL"
     */
    public URL fetchHelpSetURL() {
        return getClass().getResource(getHelpSetName());
    }

    /**
     * @return name of help set.
     */
    public String getHelpSetName() {
        return ClassUtil.getShortClassName(this.getClass()) + ".hs";
    }	

            
}